# flake8: noqa

"""
    Regula FaceSDK Web API

    Regula FaceSDK Web API # Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 4.1.3
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.0.0"

# import ApiClient
from regula.facesdk.webclient.gen.api_client import ApiClient

# import Configuration
from regula.facesdk.webclient.gen.configuration import Configuration

# import exceptions
from regula.facesdk.webclient.gen.exceptions import OpenApiException
from regula.facesdk.webclient.gen.exceptions import ApiAttributeError
from regula.facesdk.webclient.gen.exceptions import ApiTypeError
from regula.facesdk.webclient.gen.exceptions import ApiValueError
from regula.facesdk.webclient.gen.exceptions import ApiKeyError
from regula.facesdk.webclient.gen.exceptions import ApiException
